============
Installation
============

At the command line::

    $ pip install fuzzyfinder

Or::
    
    $ easy_install fuzzyfinder 
    
Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv fuzzyfinder
    $ pip install fuzzyfinder
